package
Version:
v0.0.0-...-3c70edb
Opens a new window with list of versions in this module.
Published: Jun 3, 2025
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CreateAccountRequest struct {
Owner string `json:"owner" binding:"required"`
Currency string `json:"currency" binding:"required,currency"`
}
type CreateAccountResponse struct {
IDAccount int64 `json:"id_account"`
Owner string `json:"owner"`
Currency string `json:"currency"`
}
type GetAccountRequest struct {
IDAccount int64 `uri:"id_account" binding:"required,min=1"`
}
type GetAccountResponse struct {
IDAccount int64 `json:"id_account"`
Owner string `json:"owner"`
Currency string `json:"currency"`
Balance int64 `json:"balance"`
}
type ListAccountRequest struct {
PageID int32 `form:"page_id" binding:"required,min=1"`
PageSize int32 `form:"page_size" binding:"required,min=5,max=10"`
}
type TransferRequest struct {
FromAccountID int64 `json:"from_account_id" binding:"required,min=1"`
ToAccountID int64 `json:"to_account_id" binding:"required,min=1"`
Amount int64 `json:"amount" binding:"required,min=1"`
Currency string `json:"currency" binding:"required,currency"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.